@@ -59,7 +59,9 @@ venneuler <- function(combinations, weights, ...) {
 }
 
 ## Note: in col.fn we need more croma and less luminance than usual, because we'll be plotting with reduced alpha
-plot.VennDiagram <- function(x, col, col.fn = function(col) hcl(col * 360, 130, 60), alpha=0.3, main=NULL, edges=200, border=NA, col.txt=1, cex=1, font=NULL, family="", ...) {
+plot.VennDiagram <- function(x, col, col.fn = function(col) hcl(col * 360, 130, 60), alpha=0.3, main=NULL, edges=200, border=NA, col.txt=1, cex=1, lwd=1, lty=1, font=NULL, family="", ...) {
+  if (length(edges) != 1 || !is.numeric(edges) || !is.finite(edges) || edges < 3)
+    stop("invalid number of edges specified")
   # calculate total extents
   xtp <- x$centers + x$diameters / 2
   xtm <- x$centers - x$diameters / 2
@@ -72,7 +74,7 @@ plot.VennDiagram <- function(x, col, col.fn = function(col) hcl(col * 360, 130,
   n <- length(x$diameters)
   if (missing(col)) col <- col.fn(x$colors)
   if (length(col) < n) col <- rep(col, length.out=n)
-  if (!is.na(alpha)) {
+  if (!any(is.na(alpha))) {
     col <- col2rgb(col) / 255
     col <- rgb(col[1,], col[2,], col[3,], alpha)
   }
@@ -81,9 +83,13 @@ plot.VennDiagram <- function(x, col, col.fn = function(col) hcl(col * 360, 130,
   sx <- cos(s) / 2 # VD uses diameter, not radius
   sy <- sin(s) / 2
   if (!is.null(border)) border <- rep(border, length.out=n)
+  lty <- rep(lty, length.out=n)
+  lwd <- rep(lwd, length.out=n)
+
   # plot all circles
   for (i in seq.int(n))
-    polygon(x$centers[i, 1] +  x$diameters[i] * sx, x$centers[i, 2] + x$diameters[i] * sy, col = col[i], border = border[i])
+      polygon(x$centers[i, 1] +  x$diameters[i] * sx, x$centers[i, 2] + x$diameters[i] * sy,
+              col = col[i], border = border[i], lty = lty[i], lwd = lwd[i])
   # if col.txt is not NA, plot the circle text
   if (!all(is.na(col.txt))) text(x$centers, x$labels, col=col.txt, cex=cex, font=font, family=family)
   # finish with title
